#
# spec file for package cilium
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         cilium
%global repo            cilium
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%define cni_bin_dir     %{_libexecdir}/cni

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           cilium
Version:        1.0.0
Release:        lp150.1.28
Summary:        Linux Native, HTTP Aware Networking and Security for Containers
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/cilium/cilium
Source0:        https://github.com/cilium/cilium/archive/v%{version}.tar.gz
BuildRequires:  clang
BuildRequires:  git
BuildRequires:  glibc-devel
BuildRequires:  glibc-devel-32bit glibc-32bit
BuildRequires:  go
BuildRequires:  golang-github-jteeuwen-go-bindata
BuildRequires:  libelf-devel
BuildRequires:  llvm
BuildRequires:  protobuf-devel
BuildRequires:  shadow
BuildRequires:  unzip
Requires:       clang
Requires:       llvm
Requires:       protobuf-c
Requires:       util-linux
ExclusiveArch:  aarch64 x86_64
Requires(post): %fillup_prereq

%description
Cilium is a software for providing, and transparently securing, network
connectivity, and for load-balancing between application containers and
services deployed using Linux container management platforms like Docker and
Kubernetes.

%prep
mkdir -p %{name}-%{version}/src/github.com/cilium/%{name}
tar -zxf %{SOURCE0} --strip-components=1 -C %{name}-%{version}/src/github.com/cilium/%{name}

%build
export GOPATH=$(pwd)/%{name}-%{version}
export CILIUM_DISABLE_ENVOY_BUILD=1
cd %{name}-%{version}/src/github.com/cilium/%{name}
sed -i '/groupadd /s/^/#/'  daemon/Makefile
make precheck
make build

%install
cd %{name}-%{version}/src/github.com/cilium/%{name}
%make_install

for service in cilium cilium-docker cilium-etcd cilium-consul; do
        install -D -m 644 contrib/systemd/${service}.service \
        %{buildroot}%{_unitdir}/${service}.service
done

install -D -m 0644 contrib/systemd/cilium %{buildroot}%{_fillupdir}/sysconfig.cilium
install -D -m 0644 plugins/cilium-cni/10-cilium-cni.conf %{buildroot}%{_sysconfdir}/cni/net.d/
install -D  %{buildroot}/opt/cni/bin/cilium-cni "%{buildroot}%{cni_bin_dir}/cilium-cni"

rm %{buildroot}/opt/cni/bin/cilium-cni

%pre
%service_add_pre cilium-consul.service cilium-docker.service cilium-etcd.service cilium.service

%post
%service_add_post cilium-consul.service cilium-docker.service cilium-etcd.service cilium.service
%service_add_post cilium.service
%{fillup_only -n cilium}

%preun
%service_del_preun cilium-consul.service cilium-docker.service cilium-etcd.service cilium.service

%postun
%service_del_postun cilium-consul.service cilium-docker.service cilium-etcd.service cilium.service

%files
%dir %{_sysconfdir}/cni
%dir %{_sysconfdir}/cni/net.d
%dir %{cni_bin_dir}

%{_sysconfdir}/bash_completion.d/cilium
%config(noreplace) %{_sysconfdir}/cni/net.d/10-cilium-cni.conf
%{_fillupdir}/sysconfig.cilium
%{_usr}/lib/systemd/system/cilium-consul.service
%{_usr}/lib/systemd/system/cilium-docker.service
%{_usr}/lib/systemd/system/cilium-etcd.service
%{_usr}/lib/systemd/system/cilium.service
%{_bindir}/cilium
%{_bindir}/cilium-agent
%{_bindir}/cilium-docker
%{_bindir}/cilium-map-migrate
%{_bindir}/cilium-node-monitor
%{_bindir}/cilium-health
%{_bindir}/cilium-bugtool
%{cni_bin_dir}/cilium-cni

%changelog
* Wed Apr 25 2018 ndas@suse.de
- Updated to v1.0.0
  Bugfixes Changes:
  * etcd: Clear the etcd status error when connectivity is OK (3824, @rlenglet)
  * ipcache: Fix ipcache deletion of old identities on update (3865, @rlenglet)
  * bpf: Fix tracing message for egress policy (3806, @joestringer)
    [- envoy-optional.patch]
- use url for source
* Wed Apr 18 2018 ndas@suse.de
- skip doc, less depedency
- remove libelf1, zypper/rpm should auto resolve
- define _fillupdir if not so
* Mon Apr 16 2018 ndas@suse.de
- clean up spec file
- use %%fillup_only for cilium sysconfig
- move cilium-cni to %%{_libexecdir}/cni like all other cni-plugins
* Mon Apr 16 2018 jengelh@inai.de
- Combine %%service_* macro calls to reduce generated code.
- Trim filler wording from description.
- Use modern tar invocation syntax.
* Mon Apr  9 2018 mrostecki@suse.com
- Updated to v1.0.0-rc10
  * API preparation for 1.0
    Changed the base prefix of the API from /v1beta to /v1 tada. The API will become stable with the 1.0 release. This makes client binaries with version < 1.0.0-rc10.
  * Bugfixes Changes
    policymap: Avoid using golang arrays in entry (#3506, @joestringer)
    etcd: Run etcd version check in the background (#3499, @tgraf)
    Test: Fix bugtool on kubernetes 1.7 (#3487, @eloycoto)
    Fix L4-only policy egress to world and CIDR-only egress to world (#3486, @joestringer)
    proxy: Use the same proxy map size as in BPF (#3485, @rlenglet)
    bpf: Do not route packets from egress proxy back into cilium_host (#3473, @tgraf)
    Continue to show timestamps in error cases in CiliumNetworkPolicy NodeStatus. (#3461, @aanm)
    policy: Add missing EntitySlice autogen code (#3458, @raybejjani)
    Fix l3-dependent L4/L7 rules applying to CIDR egress traffic (#3434, @joestringer)
  Other Changes
    bugtool: add ip rule and cilium-health status commands (#3500, @ianvernon)
    Policy: Kafka multi-topic request support (#3445, @manalibhutiyani)
- build cilium without envoy
  [+envoy-optional.patch]
* Fri Jan 19 2018 ndas@suse.de
- Updated to v1.0.0-rc2
  * Major Changes
    Tech preview of Envoy as Cilium HTTP proxy, adding HTTP2 and gRPC support. (#1580, @jrajahalme)
    Introduce "cilium-health", a new tool for investigating cluster connectivity issues. (#2052, @joestringer)
    cilium-agent collects and serves prometheus metrics (#2127, @raybejjani)
    bugtool and debuginfo (#2044, @scanf)
    Add nightly test infrastructure (#2212, @ianvernon)
    Separate ingress and egress default deny modes with better control (#2156, @manalibhutiyani)
    k8s: add support for IPBlock and Egress Rules with IPBlock (#2096, @ianvernon)
    Kafka: Support access logging for Kafka requests/responses (#1870, @manalibhutiyani)
    Added cilium endpoint log command that returns the endpoint's status log (#2060, @raybejjani)
    Change endpoint status log in cilium endpoint get to show only the most recent log
    Routes connecting the host to the Cilium IP space is now implemented as
    individual route for each node in the cluster. This allows to assign IPs
    which are part of the cluster CIDR to endpoints outside of the cluster
    as long as the IPs are never used as node CIDRs. (#1888, @tgraf)
    Standardized structured logging (#1801, #1828, #1836, #1826, #1833, #1834, #1827, #1829, #1832, #1835, @raybejjani)
  * Bugfixes Changes
    Fix L4Filter JSON marshalling (#1871, @joestringer)
    Fix swapped src dst IPs on Conntrack related messages on the monitor's output (#2228, @aanm)
    Fix output of cilium endpoint list for endpoints using multiple labels. (#2225, @aanm)
    bpf: fix verifier error in dameon debug mode with newer LLVM versions (#2181, @borkmann)
    pkg/kvstore: fixed race in internal mutex map (#2179, @aanm)
    Proxy ingress policy fix for LLVM 4.0 and greater. Resolves return code 500 'Internal Error' seen with some policies and traffic patterns. (#2162, @jrfastab)
    Printing patch clang and kernel patch versions when starting cilium. (#2137, @aanm)
    Clean up Connection Tracking entries when a new policy no longer allows it. #1667, #1823 (#2136, @aanm)
    k8s: fix data race in d.loadBalancer.K8sEndpoints (#2129, @aanm)
    Add internal queue for k8s watcher updates #1966 (#2123, @aanm)
    k8s: fix missing deep copy when updating status (#2115, @aanm)
    Accept traffic to Cilium in FORWARD chain (#2112, @tgraf)
    Also clear the masquerade bit in the FORWARD chain to skip the masquerade rule installed by kube-proxy
    Fix SNAT issue in combination with kube-proxy, when masquerade rule installed by kube-proxy takes precedence over rule installed by Cilium. (#2108, @tgraf)
    Fixed infinite loop when importing CNP to kubernetes with an empty kafka version (#2090, @aanm)
    Mark cilium pod as CriticalPod in the DaemonSet (#2024, @manalibhutiyani)
    proxy: Provide identities { host | world | cluster } in SourceEndpoint (#2022, @manalibhutiyani)
    In kubernetes mode, fixed bug that was allowing cilium to start up even if the kubernetes api-server was not reachable #1973 (#2014, @aanm)
    Support policy with EndpointSelector missing (#1987, @raybejjani)
    Implemented deep copy functionality when receiving events from kubernetes watcher #1885 (#1986, @aanm)
    pkg/labels: Filter out pod-template-generation label (#1979, @michi-covalent)
    bpf: Double timeout on building BPF programs (#1949, @raybejjani)
    policy: add PolicyTrace msg to AllowsRLocked() when L4 policies not evaluated (#1939, @gnahckire)
    Handle Kafka responses correctly (#1924, @manalibhutiyani)
    bpf: Avoid excessive proxymap updates (#2210, @joestringer)
    cilium-agent correctly restarts listening for CiliumNetworkPolicy changes when it sees decoding errors (#1899, @raybejjani)
* Wed Nov  8 2017 ndas@suse.de
- Initial version 0.12
